import { __decorate } from "tslib";
import { css, html, observable } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
/**
 * The AG Boolean Renderer element.
 * @public
 * @tagname %%prefix%%-boolean-renderer
 */
export class BooleanRenderer extends FoundationElement {
    init(params) {
        if (!params)
            return;
        this.params = params;
    }
    getGui() {
        return this;
    }
    destroy() { }
    refresh(params) {
        return true;
    }
}
__decorate([
    observable
], BooleanRenderer.prototype, "params", void 0);
/**
 * The AG Boolean Renderer Styles.
 * @public
 */
export const agBooleanRendererStyles = css `
  :host {
    align-center: center;
    display: flex;
    height: 100%;
  }
`;
/**
 * Get a Design System prefixed Checkbox template.
 * @param designSystem - The design system prefix to use. Defaults to 'foundation'.
 * @returns A Checkbox component template prefixed with the correct design system.
 * @public
 */
export const getAgBooleanRendererTemplate = (designSystem = 'foundation') => {
    const checkboxComponent = `${designSystem}-checkbox`;
    return html `
    <${checkboxComponent}
      @change="${(x) => { var _a; return (_a = x.params) === null || _a === void 0 ? void 0 : _a.changeHandler(x.params); }}"
      checked="${(x) => { var _a; return (_a = x.params) === null || _a === void 0 ? void 0 : _a.value; }}"
      readonly="${(x) => { var _a; return (_a = x.params) === null || _a === void 0 ? void 0 : _a.readonly; }}"
    ></${checkboxComponent}>
  `;
};
/**
 * A function that returns a Foundation Boolean Renderer registration for configuring the component with a DesignSystem.
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-boolean-renderer\>
 */
export const foundationAgBooleanRenderer = BooleanRenderer.compose({
    baseName: 'boolean-renderer',
    styles: agBooleanRendererStyles,
    template: getAgBooleanRendererTemplate(),
});
